@@ -1,4 +1,4 @@
-__all__ = ['Blocking', 'greedy_set_cover']
+__all__ = ['Blocking', 'greedy_set_cover', 'all_rules']
 
 from .blocking import Blocking
 from .blocking_rules import all_rules
